<!--
The following checklist points should all be checked before merging the PR.

Please replace xxx by your issue number (leave the prefixing '#').
-->

### Pull Request for the issue #xxx
- [ ] These changes were tested with real data and unit tests cover them as well.
- [ ] The relevant documentation has been added (or updated).
- [ ] A short description of the changes has been added to doc/source/references/release_notes.rst

### Describe the changes you made
